# py-office
 a python work office.
 
### the goal of this project is to build an easy to use office to manage data, analyze and further machine learning, exposing powerful features of python library to end users through GUI.
### another main concern is to bring machine learning to people who do not know how to code.
powerful functions and features of the python library is by used of people who knows programming. End users lack the necessury knowledge to make use of them and may not even aware of the existance of such thing, ***they have no will to learn a programming language.***

> ***everyone should learn how to code :)***
 
### [py-office-sheet](https://github.com/YC-Lammy/py-office-sheet) : a gui spreadsheet based on numpy to process data efficienly 

### [py-office-learn](https://github.com/YC-Lammy/py-office-learn) :  a gui for machine learning base on keras (constructing)

## install
### command line install:
```
pip install py-office
```
optional desktop icon install(GUI entry):
```
py-office setup
```
pip will install every component of the py-office listed above

standalone py-office component is also avaliable on pip, such as:
```
pip install py-office-sheet
```
### installer install:
linux:
```
./pyoffice_install_{your_os}.sh
```
mac os:
```
not yet
```
windows:
```
not yet
```
